@@ -14,17 +14,20 @@ resource_handler_config = ResourceHandlerConfigModel(
 
 
 class EnergyAdapter(ActuatorAdapter):
-    """
-    Adapter for Energy Hardware Object, a web socket is used to communicate
-    information on longer running processes.
+    """Adapter for Energy Hardware Object.
+
+    A web socket is used to communicate information on longer running processes.
     """
 
     SUPPORTED_TYPES: ClassVar[list[object]] = [AbstractEnergy.AbstractEnergy]
 
-    def __init__(self, ho, role, app):
-        """
+    def __init__(  # noqa: D417
+        self, ho, role, app
+    ):
+        """Initialize.
+
         Args:
-            (object): Hardware object.
+            ho (object): Hardware object.
         """
         super().__init__(ho, role, app, resource_handler_config)
         self._add_adapter("wavelength", self._ho, WavelengthAdapter)
