@@ -2,7 +2,6 @@ import contextlib
 import logging
 
 from mxcubecore import HardwareRepository as HWR
-from mxcubecore import queue_entry as qe
 from mxcubecore.HardwareObjects.Harvester import HarvesterState
 from mxcubecore.model import queue_model_objects as qmo
 
@@ -91,17 +90,6 @@ def harvester_contents_update():
     server.emit("harvester_contents_update")
 
 
-def centring_started(method, *args):
-    msg = {"method": method}
-
-    if method in ["Computer automatic"]:
-        msg = {"method": qe.CENTRING_METHOD.LOOP}
-    elif method in [HWR.beamline.diffractometer.CENTRING_METHOD_MANUAL]:
-        msg = {"method": qe.CENTRING_METHOD.MANUAL}
-
-    server.emit("sample_centring", msg, namespace="/hwr")
-
-
 def get_task_state(entry):
     node_id = entry.get_data_model()._node_id
     _, state = mxcube.queue.get_node_state(node_id)
@@ -340,10 +328,6 @@ def collect_started(*args, **kwargs):
             logging.getLogger("HWR").error("error sending message: " + str(msg))
 
 
-def grid_result_available(shape):
-    server.emit("grid_result_available", {"shape": shape}, namespace="/hwr")
-
-
 def energy_scan_finished(pk, ip, rm, sample):
     server.emit(
         "energy_scan_result",
